@@ -10,7 +10,7 @@ namespace phpmock;
  * @license http://www.wtfpl.net/txt/copying/ WTFPL
  * @see Mock
  */
-class MockTest extends AbstractMockTest
+class MockTest extends AbstractMockTestCase
 {
     protected function defineFunction($namespace, $functionName)
     {
@@ -32,8 +32,6 @@ class MockTest extends AbstractMockTest
 
     /**
      * Tests enable().
-     *
-     * @test
      */
     public function testEnable()
     {
@@ -51,8 +49,6 @@ class MockTest extends AbstractMockTest
 
     /**
      * Tests disabling and enabling again.
-     *
-     * @test
      */
     public function testReenable()
     {
@@ -71,8 +67,6 @@ class MockTest extends AbstractMockTest
 
     /**
      * Tests disableAll().
-     *
-     * @test
      */
     public function testDisableAll()
     {
